@@ -29,26 +29,21 @@ def tvd(y, lamda, num_iter=20, return_cost=False):
 
     It is also included in the references directory of this repository.
     """
-    import numpy as np
     from scipy import sparse
-    from scipy.sparse import linalg  # noqa weird scipy import thing
+    import numpy as np
 
     if not isinstance(y, np.ndarray):
         raise ValueError("tvd can only be used on numpy arrays")
-
     if not len(y.shape) == 1:
         raise ValueError("tvd can only be used on flat arrays. Try y.flatten()")
-
     if np.any(np.isnan(y)):
         raise ValueError("tvd must not contain any nans")
-
     N = len(y)
     y = np.expand_dims(y, -1)
     cost = np.zeros(num_iter)
-    I = sparse.identity(N, format="csr")  # noqa
-    D = I[1:N, :] - I[: N - 1, :]
+    I = sparse.identity(N, format="csr")
+    D = I[1:N, :] - I[: N - 1, :]  # type: ignore
     DDT = D @ D.T
-
     x = y
     Dx = D @ x
     Dy = D @ y
@@ -57,8 +52,7 @@ def tvd(y, lamda, num_iter=20, return_cost=False):
         x = y - np.expand_dims(D.T @ sparse.linalg.spsolve(F, Dy), -1)
         Dx = D @ x
         cost[k] = 0.5 * np.sum((x - y) ** 2) + lamda * np.sum(np.abs(Dx))
-
     if return_cost:
-        return x.flatten(), cost
+        return (x.flatten(), cost)
     else:
         return x.flatten()
